shift — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# shift

poscar_modify.shift(amount: List[float] | np.ndarray, cartesian: bool = False)

  Shift all the positions by amount, given in Cartesian or direct coordinates. The PBCs are always enforced (i.e. [0,1] in direct coords). If amount = [0,0,0] it just applies the perodic boundary conditions.

  Parameters:

    - amount (List[float] | np.ndarray) – [X,Y,Z] the shift along each basis vector or along Cartesian axis.

    - cartesian (bool) – is the amount given in Cartesian (True) or direct (False) coords? Default False